<a id="mypy-boto3-personalize"></a>

# mypy-boto3-personalize

[![PyPI - types-aiobotocore-personalize](https://img.shields.io/pypi/v/types-aiobotocore-personalize.svg?color=blue)](https://pypi.org/project/types-aiobotocore-personalize)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/types-aiobotocore-personalize.svg?color=blue)](https://pypi.org/project/types-aiobotocore-personalize)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)
[![PyPI - Downloads](https://img.shields.io/pypi/dm/types-aiobotocore-personalize?color=blue)](https://pypistats.org/packages/types-aiobotocore-personalize)

![boto3.typed](https://github.com/vemel/mypy_boto3_builder/raw/main/logo.png)

Type annotations for
[boto3.Personalize 1.20.47](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/personalize.html#Personalize)
service compatible with [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[Emacs](https://www.gnu.org/software/emacs/),
[Sublime Text](https://www.sublimetext.com/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright) and other tools.

Generated by
[mypy-boto3-builder 6.4.2](https://github.com/vemel/mypy_boto3_builder).

More information can be found on
[boto3-stubs](https://pypi.org/project/boto3-stubs/) page and in
[types-aiobotocore-personalize docs](https://vemel.github.io/types_aiobotocore_docs/types_aiobotocore_personalize/)

See how it helps to find and fix potential bugs:

![boto3-stubs demo](https://github.com/vemel/mypy_boto3_builder/raw/main/demo.gif)

- [mypy-boto3-personalize](#mypy-boto3-personalize)
  - [How to install](#how-to-install)
    - [VSCode extension](#vscode-extension)
    - [From PyPI with pip](#from-pypi-with-pip)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)

<a id="how-to-install"></a>

## How to install

<a id="vscode-extension"></a>

### VSCode extension

Add
[AWS Boto3](https://marketplace.visualstudio.com/items?itemName=Boto3typed.boto3-ide)
extension to your VSCode and run `AWS boto3: Quick Start` command.

Click `Modify` and select `boto3 common` and `Personalize`.

<a id="from-pypi-with-pip"></a>

### From PyPI with pip

Install `types-aiobotocore` for `Personalize` service.

```bash
# install with aiobotocore type annotations
python -m pip install 'types-aiobotocore[personalize]'

# Lite version does not provide session.create_client overloads
# it is more RAM-friendly, but requires explicit type annotations
python -m pip install 'types-aiobotocore-lite[personalize]'

# standalone installation
python -m pip install types-aiobotocore-personalize
```

<a id="usage"></a>

## Usage

<a id="vscode"></a>

### VSCode

- Install
  [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install
  [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `types-aiobotocore[personalize]` in your environment:
  `python -m pip install 'types-aiobotocore[personalize]'`

Both type checking and auto-complete should work for `Personalize` service. No
explicit type annotations required, write your `boto3` code as usual.

<a id="pycharm"></a>

### PyCharm

- Install `types-aiobotocore[personalize]` in your environment:
  `python -m pip install 'types-aiobotocore[personalize]'`

Both type checking and auto-complete should work for `Personalize` service. No
explicit type annotations required, write your `aiobotocore` code as usual.
Auto-complete can be slow on big projects or if you have a lot of installed
`types-aiobotocore` submodules.

<a id="other-ides"></a>

### Other IDEs

Not tested, but as long as your IDE supports `mypy` or `pyright`, everything
should work.

<a id="mypy"></a>

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `types-aiobotocore[personalize]` in your environment:
  `python -m pip install 'types-aiobotocore[personalize]'`
- Run `mypy` as usual

Type checking should work for `Personalize` service. No explicit type
annotations required, write your `aiobotocore` code as usual.

<a id="pyright"></a>

### pyright

- Install `pyright`: `yarn global add pyright`
- Install `types-aiobotocore[personalize]` in your environment:
  `python -m pip install 'types-aiobotocore[personalize]'`
- Optionally, you can install `boto3-stubs` to `typings` folder.

Type checking should work for `Personalize` service. No explicit type
annotations required, write your `aiobotocore` code as usual.

<a id="explicit-type-annotations"></a>

## Explicit type annotations

<a id="client-annotations"></a>

### Client annotations

`PersonalizeClient` provides annotations for
`session.create_client("personalize")`.

```python
from aiobotocore.session import get_session

from types_aiobotocore_personalize import PersonalizeClient

session = get_session()
async with session.create_client("personalize") as client:
    client: PersonalizeClient
    # now client usage is checked by mypy and IDE should provide code auto-complete
```

<a id="paginators-annotations"></a>

### Paginators annotations

`types_aiobotocore_personalize.paginator` module contains type annotations for
all paginators.

````python
from aiobotocore.session import get_session

from types_aiobotocore_personalize import PersonalizeClient
from types_aiobotocore_personalize.paginator import (
    ListBatchInferenceJobsPaginator,
    ListBatchSegmentJobsPaginator,
    ListCampaignsPaginator,
    ListDatasetExportJobsPaginator,
    ListDatasetGroupsPaginator,
    ListDatasetImportJobsPaginator,
    ListDatasetsPaginator,
    ListEventTrackersPaginator,
    ListFiltersPaginator,
    ListRecipesPaginator,
    ListRecommendersPaginator,
    ListSchemasPaginator,
    ListSolutionVersionsPaginator,
    ListSolutionsPaginator,
)

session = get_session()
async with session.create_client("personalize") as client:
    client: PersonalizeClient

    # Explicit type annotations are optional here
    # Type should be correctly discovered by mypy and IDEs
    # VSCode requires explicit type annotations
        list_batch_inference_jobs_paginator: ListBatchInferenceJobsPaginator = client.get_paginator("list_batch_inference_jobs")
        list_batch_segment_jobs_paginator: ListBatchSegmentJobsPaginator = client.get_paginator("list_batch_segment_jobs")
        list_campaigns_paginator: ListCampaignsPaginator = client.get_paginator("list_campaigns")
        list_dataset_export_jobs_paginator: ListDatasetExportJobsPaginator = client.get_paginator("list_dataset_export_jobs")
        list_dataset_groups_paginator: ListDatasetGroupsPaginator = client.get_paginator("list_dataset_groups")
        list_dataset_import_jobs_paginator: ListDatasetImportJobsPaginator = client.get_paginator("list_dataset_import_jobs")
        list_datasets_paginator: ListDatasetsPaginator = client.get_paginator("list_datasets")
        list_event_trackers_paginator: ListEventTrackersPaginator = client.get_paginator("list_event_trackers")
        list_filters_paginator: ListFiltersPaginator = client.get_paginator("list_filters")
        list_recipes_paginator: ListRecipesPaginator = client.get_paginator("list_recipes")
        list_recommenders_paginator: ListRecommendersPaginator = client.get_paginator("list_recommenders")
        list_schemas_paginator: ListSchemasPaginator = client.get_paginator("list_schemas")
        list_solution_versions_paginator: ListSolutionVersionsPaginator = client.get_paginator("list_solution_versions")
        list_solutions_paginator: ListSolutionsPaginator = client.get_paginator("list_solutions")
    ```







### Literals

`types_aiobotocore_personalize.literals` module contains literals extracted from shapes
that can be used in user code for type checking.

```python
from types_aiobotocore_personalize.literals import (
    DomainType,
    IngestionModeType,
    ListBatchInferenceJobsPaginatorName,
    ListBatchSegmentJobsPaginatorName,
    ListCampaignsPaginatorName,
    ListDatasetExportJobsPaginatorName,
    ListDatasetGroupsPaginatorName,
    ListDatasetImportJobsPaginatorName,
    ListDatasetsPaginatorName,
    ListEventTrackersPaginatorName,
    ListFiltersPaginatorName,
    ListRecipesPaginatorName,
    ListRecommendersPaginatorName,
    ListSchemasPaginatorName,
    ListSolutionVersionsPaginatorName,
    ListSolutionsPaginatorName,
    ObjectiveSensitivityType,
    RecipeProviderType,
    TrainingModeType,
    ServiceName,
    PaginatorName,
)

def check_value(value: DomainType) -> bool:
    ...
````

### Typed dictionaries

`types_aiobotocore_personalize.type_defs` module contains structures and shapes
assembled to typed dictionaries for additional type checking.

```python
from types_aiobotocore_personalize.type_defs import (
    AlgorithmImageTypeDef,
    AlgorithmTypeDef,
    AutoMLConfigTypeDef,
    AutoMLResultTypeDef,
    BatchInferenceJobConfigTypeDef,
    BatchInferenceJobInputTypeDef,
    BatchInferenceJobOutputTypeDef,
    BatchInferenceJobSummaryTypeDef,
    BatchInferenceJobTypeDef,
    BatchSegmentJobInputTypeDef,
    BatchSegmentJobOutputTypeDef,
    BatchSegmentJobSummaryTypeDef,
    BatchSegmentJobTypeDef,
    CampaignConfigTypeDef,
    CampaignSummaryTypeDef,
    CampaignTypeDef,
    CampaignUpdateSummaryTypeDef,
    CategoricalHyperParameterRangeTypeDef,
    ContinuousHyperParameterRangeTypeDef,
    CreateBatchInferenceJobRequestRequestTypeDef,
    CreateBatchInferenceJobResponseTypeDef,
    CreateBatchSegmentJobRequestRequestTypeDef,
    CreateBatchSegmentJobResponseTypeDef,
    CreateCampaignRequestRequestTypeDef,
    CreateCampaignResponseTypeDef,
    CreateDatasetExportJobRequestRequestTypeDef,
    CreateDatasetExportJobResponseTypeDef,
    CreateDatasetGroupRequestRequestTypeDef,
    CreateDatasetGroupResponseTypeDef,
    CreateDatasetImportJobRequestRequestTypeDef,
    CreateDatasetImportJobResponseTypeDef,
    CreateDatasetRequestRequestTypeDef,
    CreateDatasetResponseTypeDef,
    CreateEventTrackerRequestRequestTypeDef,
    CreateEventTrackerResponseTypeDef,
    CreateFilterRequestRequestTypeDef,
    CreateFilterResponseTypeDef,
    CreateRecommenderRequestRequestTypeDef,
    CreateRecommenderResponseTypeDef,
    CreateSchemaRequestRequestTypeDef,
    CreateSchemaResponseTypeDef,
    CreateSolutionRequestRequestTypeDef,
    CreateSolutionResponseTypeDef,
    CreateSolutionVersionRequestRequestTypeDef,
    CreateSolutionVersionResponseTypeDef,
    DataSourceTypeDef,
    DatasetExportJobOutputTypeDef,
    DatasetExportJobSummaryTypeDef,
    DatasetExportJobTypeDef,
    DatasetGroupSummaryTypeDef,
    DatasetGroupTypeDef,
    DatasetImportJobSummaryTypeDef,
    DatasetImportJobTypeDef,
    DatasetSchemaSummaryTypeDef,
    DatasetSchemaTypeDef,
    DatasetSummaryTypeDef,
    DatasetTypeDef,
    DefaultCategoricalHyperParameterRangeTypeDef,
    DefaultContinuousHyperParameterRangeTypeDef,
    DefaultHyperParameterRangesTypeDef,
    DefaultIntegerHyperParameterRangeTypeDef,
    DeleteCampaignRequestRequestTypeDef,
    DeleteDatasetGroupRequestRequestTypeDef,
    DeleteDatasetRequestRequestTypeDef,
    DeleteEventTrackerRequestRequestTypeDef,
    DeleteFilterRequestRequestTypeDef,
    DeleteRecommenderRequestRequestTypeDef,
    DeleteSchemaRequestRequestTypeDef,
    DeleteSolutionRequestRequestTypeDef,
    DescribeAlgorithmRequestRequestTypeDef,
    DescribeAlgorithmResponseTypeDef,
    DescribeBatchInferenceJobRequestRequestTypeDef,
    DescribeBatchInferenceJobResponseTypeDef,
    DescribeBatchSegmentJobRequestRequestTypeDef,
    DescribeBatchSegmentJobResponseTypeDef,
    DescribeCampaignRequestRequestTypeDef,
    DescribeCampaignResponseTypeDef,
    DescribeDatasetExportJobRequestRequestTypeDef,
    DescribeDatasetExportJobResponseTypeDef,
    DescribeDatasetGroupRequestRequestTypeDef,
    DescribeDatasetGroupResponseTypeDef,
    DescribeDatasetImportJobRequestRequestTypeDef,
    DescribeDatasetImportJobResponseTypeDef,
    DescribeDatasetRequestRequestTypeDef,
    DescribeDatasetResponseTypeDef,
    DescribeEventTrackerRequestRequestTypeDef,
    DescribeEventTrackerResponseTypeDef,
    DescribeFeatureTransformationRequestRequestTypeDef,
    DescribeFeatureTransformationResponseTypeDef,
    DescribeFilterRequestRequestTypeDef,
    DescribeFilterResponseTypeDef,
    DescribeRecipeRequestRequestTypeDef,
    DescribeRecipeResponseTypeDef,
    DescribeRecommenderRequestRequestTypeDef,
    DescribeRecommenderResponseTypeDef,
    DescribeSchemaRequestRequestTypeDef,
    DescribeSchemaResponseTypeDef,
    DescribeSolutionRequestRequestTypeDef,
    DescribeSolutionResponseTypeDef,
    DescribeSolutionVersionRequestRequestTypeDef,
    DescribeSolutionVersionResponseTypeDef,
    EventTrackerSummaryTypeDef,
    EventTrackerTypeDef,
    FeatureTransformationTypeDef,
    FilterSummaryTypeDef,
    FilterTypeDef,
    GetSolutionMetricsRequestRequestTypeDef,
    GetSolutionMetricsResponseTypeDef,
    HPOConfigTypeDef,
    HPOObjectiveTypeDef,
    HPOResourceConfigTypeDef,
    HyperParameterRangesTypeDef,
    IntegerHyperParameterRangeTypeDef,
    ListBatchInferenceJobsRequestRequestTypeDef,
    ListBatchInferenceJobsResponseTypeDef,
    ListBatchSegmentJobsRequestRequestTypeDef,
    ListBatchSegmentJobsResponseTypeDef,
    ListCampaignsRequestRequestTypeDef,
    ListCampaignsResponseTypeDef,
    ListDatasetExportJobsRequestRequestTypeDef,
    ListDatasetExportJobsResponseTypeDef,
    ListDatasetGroupsRequestRequestTypeDef,
    ListDatasetGroupsResponseTypeDef,
    ListDatasetImportJobsRequestRequestTypeDef,
    ListDatasetImportJobsResponseTypeDef,
    ListDatasetsRequestRequestTypeDef,
    ListDatasetsResponseTypeDef,
    ListEventTrackersRequestRequestTypeDef,
    ListEventTrackersResponseTypeDef,
    ListFiltersRequestRequestTypeDef,
    ListFiltersResponseTypeDef,
    ListRecipesRequestRequestTypeDef,
    ListRecipesResponseTypeDef,
    ListRecommendersRequestRequestTypeDef,
    ListRecommendersResponseTypeDef,
    ListSchemasRequestRequestTypeDef,
    ListSchemasResponseTypeDef,
    ListSolutionVersionsRequestRequestTypeDef,
    ListSolutionVersionsResponseTypeDef,
    ListSolutionsRequestRequestTypeDef,
    ListSolutionsResponseTypeDef,
    OptimizationObjectiveTypeDef,
    PaginatorConfigTypeDef,
    RecipeSummaryTypeDef,
    RecipeTypeDef,
    RecommenderConfigTypeDef,
    RecommenderSummaryTypeDef,
    RecommenderTypeDef,
    RecommenderUpdateSummaryTypeDef,
    ResponseMetadataTypeDef,
    S3DataConfigTypeDef,
    SolutionConfigTypeDef,
    SolutionSummaryTypeDef,
    SolutionTypeDef,
    SolutionVersionSummaryTypeDef,
    SolutionVersionTypeDef,
    StopSolutionVersionCreationRequestRequestTypeDef,
    TunedHPOParamsTypeDef,
    UpdateCampaignRequestRequestTypeDef,
    UpdateCampaignResponseTypeDef,
    UpdateRecommenderRequestRequestTypeDef,
    UpdateRecommenderResponseTypeDef,
)

def get_structure() -> AlgorithmImageTypeDef:
    return {
      ...
    }
```

## Versioning

`types-aiobotocore-personalize` version is the same as related `boto3` version
and follows [PEP 440](https://www.python.org/dev/peps/pep-0440/) format.

## Documentation

All type annotations can be found in
[types-aiobotocore-personalize docs](https://vemel.github.io/types_aiobotocore_docs/types_aiobotocore_personalize/)

## Support and contributing

This package is auto-generated. Please reports any bugs or request new features
in [mypy-boto3-builder](https://github.com/vemel/mypy_boto3_builder/issues/)
repository.
